Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2233)

Unified Diff: src/globals.h

Issue 177683002: Mode clean-up pt 1: rename classic/non-strict mode to sloppy mode (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/full-codegen.h ('k') | src/harmony-array.js » ('j') | src/preparser.h » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/globals.h
diff --git a/src/globals.h b/src/globals.h
index 8a67632d2cd74284b1c61807608a5ed8cb071465..656e9ed42578dbdb6f8d46dba5143059da02c3ee 100644
--- a/src/globals.h
+++ b/src/globals.h
@@ -403,18 +403,15 @@ template <typename T, class P = FreeStoreAllocationPolicy> class List;
// The different language modes that V8 implements. ES5 defines two language
// modes: an unrestricted mode respectively a strict mode which are indicated by
// CLASSIC_MODE respectively STRICT_MODE in the enum. The harmony spec drafts
// for the next ES standard specify a new third mode which is called 'extended
// mode'. The extended mode is only available if the harmony flag is set. It is
// based on the 'strict mode' and adds new functionality to it. This means that
// most of the semantics of these two modes coincide.
-//
-// In the current draft the term 'base code' is used to refer to code that is
-// neither in strict nor extended mode. However, the more distinguishing term
-// 'classic mode' is used in V8 instead to avoid mix-ups.
+// TODO(rossberg): remove extended mode.
Michael Starzinger 2014/02/24 15:09:14 Looking forward to that!
enum LanguageMode {
- CLASSIC_MODE,
+ SLOPPY_MODE,
STRICT_MODE,
EXTENDED_MODE
};
@@ -426,7 +423,7 @@ enum LanguageMode {
// there is no semantic difference between the strict and the extended mode in
// the backend, so both modes are represented by the kStrictMode value.
enum StrictModeFlag {
- kNonStrictMode,
+ kSloppyMode,
kStrictMode
};
« no previous file with comments | « src/full-codegen.h ('k') | src/harmony-array.js » ('j') | src/preparser.h » ('J')
@@ -403,18 +403,15 @@ template <typename T, class P = FreeStoreAllocationPolicy> class List;
// The different language modes that V8 implements. ES5 defines two language
// modes: an unrestricted mode respectively a strict mode which are indicated by
-// CLASSIC_MODE respectively STRICT_MODE in the enum. The harmony spec drafts
+// SLOPPY_MODE respectively STRICT_MODE in the enum. The harmony spec drafts
// for the next ES standard specify a new third mode which is called 'extended
// mode'. The extended mode is only available if the harmony flag is set. It is

Powered by Google App Engine
This is Rietveld 408576698